Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1464)

Unified Diff: ui/views/controls/scrollbar/base_scroll_bar_thumb.h

Issue 2496643002: Implement Sebastien's overlay scrollbars for native UI (Views). (Closed)
Patch Set: clarify comment Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/views/controls/scrollbar/base_scroll_bar_thumb.h
diff --git a/ui/views/controls/scrollbar/base_scroll_bar_thumb.h b/ui/views/controls/scrollbar/base_scroll_bar_thumb.h
index ea16b14ecb4f6efd9b7d9da726fd902bd62572da..22358db2be98dd5da9ab39c3b803ec1ef08e50d4 100644
--- a/ui/views/controls/scrollbar/base_scroll_bar_thumb.h
+++ b/ui/views/controls/scrollbar/base_scroll_bar_thumb.h
@@ -32,8 +32,8 @@ class VIEWS_EXPORT BaseScrollBarThumb : public View {
explicit BaseScrollBarThumb(BaseScrollBar* scroll_bar);
~BaseScrollBarThumb() override;
- // Sets the size (width or height) of the thumb to the specified value.
- void SetSize(int size);
+ // Sets the length (width or height) of the thumb to the specified value.
+ void SetLength(int length);
// Retrieves the size (width or height) of the thumb.
int GetSize() const;
@@ -59,7 +59,9 @@ class VIEWS_EXPORT BaseScrollBarThumb : public View {
CustomButton::ButtonState GetState() const;
// Update our state and schedule a repaint when the mouse moves over us.
- void SetState(CustomButton::ButtonState state);
+ virtual void SetState(CustomButton::ButtonState state);
sadrul 2016/11/12 03:01:10 Can you introduce a separate OnStateChanged() or s
+
+ bool IsHorizontal() const;
BaseScrollBar* scroll_bar() { return scroll_bar_; }

Powered by Google App Engine
This is Rietveld 408576698